@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/spacious-padding
-;; Version: 0.6.0
+;; Version: 0.6.1
 ;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: convenience, focus, writing, presentation
 
@@ -127,6 +127,24 @@ When the value is nil, fall back to reasonable defaults."
   :package-version '(spacious-padding . "0.4.0")
   :group 'spacious-padding)
 
+(defface spacious-padding-subtle-mode-line-active
+  '((((class color) (min-colors 88) (background light))
+     :foreground "#0033dd")
+    (((class color) (min-colors 88) (background dark))
+     :foreground "#88aaff"))
+  "Optional face for the active mode line.
+This is something the user can defined per the documentation of
+`spacious-padding-subtle-mode-line'.")
+
+(defface spacious-padding-subtle-mode-line-inactive
+  '((((class color) (min-colors 88) (background light))
+     :foreground "#cfcfcf")
+    (((class color) (min-colors 88) (background dark))
+     :foreground "#585858"))
+  "Optional face for the inactive mode line.
+This is something the user can defined per the documentation of
+`spacious-padding-subtle-mode-line'.")
+
 (defcustom spacious-padding-subtle-mode-line nil
   "Remove the background from the mode lines and add overlines.
 
@@ -180,7 +198,12 @@ Examples of valid configurations:
 
     ;; Use color values directly.
     (setq spacious-padding-subtle-mode-line
-          \\='(:mode-line-active \"#0000ff\" :mode-line-inactive \"gray50\"))"
+          \\='(:mode-line-active \"#0000ff\" :mode-line-inactive \"gray50\"))
+
+For the convenience of the user, we define the faces
+`spacious-padding-subtle-mode-line-active' and
+`spacious-padding-subtle-mode-line-inactive', which can be used as
+described above."
   :type '(choice boolean
                  (plist
                   :key-type (choice (const :mode-line-active)
@@ -403,25 +426,26 @@ parameter value."
 (spacious-padding--define-get-frame-param "right-fringe-width" nil)
 (spacious-padding--define-get-frame-param "scroll-bar-width" 8)
 
-(defun spacious-padding-modify-frame-parameters (&optional reset)
-  "Modify all frame parameters to specify spacing.
+(defun spacious-padding-modify-frame-parameters (&optional frame reset)
+  "Modify spacing of all frames or optional FRAME.
 With optional RESET argument as non-nil, restore the default
 parameter values."
-  (modify-all-frames-parameters
-   `((internal-border-width . ,(spacious-padding--get-internal-border-width reset))
-     (right-divider-width . ,(spacious-padding--get-right-divider-width reset))
-     (left-fringe . ,(or (spacious-padding--get-left-fringe-width reset)
-                         (spacious-padding--get-fringe-width reset)))
-     (right-fringe . ,(or (spacious-padding--get-right-fringe-width reset)
-                          (spacious-padding--get-fringe-width reset)))
-     (scroll-bar-width  . ,(spacious-padding--get-scroll-bar-width reset)))))
+  (let ((parameters `((internal-border-width . ,(spacious-padding--get-internal-border-width reset))
+                      (right-divider-width . ,(spacious-padding--get-right-divider-width reset))
+                      (left-fringe . ,(or (spacious-padding--get-left-fringe-width reset)
+                                          (spacious-padding--get-fringe-width reset)))
+                      (right-fringe . ,(or (spacious-padding--get-right-fringe-width reset)
+                                           (spacious-padding--get-fringe-width reset)))
+                      (scroll-bar-width  . ,(spacious-padding--get-scroll-bar-width reset)))))
+   (if frame
+       (modify-frame-parameters frame parameters)
+     (modify-all-frames-parameters parameters))))
 
 ;;;###autoload
 (defun spacious-padding-set-parameters-of-frame (frame)
   "Set the layout parameters of FRAME and update the faces."
-  (with-selected-frame frame
-    (spacious-padding-modify-frame-parameters)
-    (spacious-padding-set-faces)))
+  (spacious-padding-modify-frame-parameters frame)
+  (spacious-padding-set-faces))
 
 (defun spacious-padding--enable-mode ()
   "Enable `spacious-padding-mode'."
@@ -434,7 +458,7 @@ parameter values."
 
 (defun spacious-padding--disable-mode ()
   "Disable `spacious-padding-mode'."
-  (spacious-padding-modify-frame-parameters :reset)
+  (spacious-padding-modify-frame-parameters nil :reset)
   (spacious-padding-unset-invisible-dividers)
   (remove-hook 'window-divider-mode-hook #'spacious-padding--enable-mode)
   (remove-hook 'enable-theme-functions #'spacious-padding-set-faces)
